@@ -1,17 +1,8 @@
 import os
 import csv
 import tempfile
-from ..executor import SQLExecutor
 
-def _build_insert_sql(table_name, fields, skip_duplicate=False):
-    """构建插入SQL语句的公共方法"""
-    field_names = ', '.join(fields)
-    placeholders = '(' + ', '.join(['%s'] * len(fields)) + ')'
-    insert_keyword = 'INSERT IGNORE' if skip_duplicate else 'INSERT'
-    return f'{insert_keyword} INTO {table_name} ({field_names}) VALUES {placeholders}'
-
-
-def insert(executor: SQLExecutor, table_name, insert_fields, skip_duplicate=False, commit=False, self_close=False, temp_dir=None):
+def insert(executor, table_name, insert_fields, skip_duplicate=False, commit=False, self_close=False, temp_dir=None):
     """
     智能SQL插入执行器方法，根据数据量自动选择最优插入策略
     
@@ -75,7 +66,72 @@ def insert(executor: SQLExecutor, table_name, insert_fields, skip_duplicate=Fals
         raise ValueError("insert_fields must be a dict or a list of dicts")
 
 
-def _bulk_insert_load_data(executor: SQLExecutor, table_name, insert_fields, skip_duplicate=False, 
+def upsert(executor, table_name, insert_fields, update_fields=None, commit=False, self_close=False):
+    """
+    智能 INSERT ... ON DUPLICATE KEY UPDATE 执行器
+    存在就更新，不存在就插入
+    单条：dict -> 直接 upsert
+    多条：list[dict] -> 批量 executemany upsert
+    
+    :param update_fields: 指定冲突时更新的字段，None 表示更新所有字段
+    示例：{'age'} 表示只更新 age 字段，其他字段保持不变
+    """
+    if isinstance(insert_fields, dict):
+        return _upsert_single(executor, table_name, insert_fields, update_fields, commit, self_close)
+    elif isinstance(insert_fields, list) and insert_fields:
+        return _upsert_batch(executor, table_name, insert_fields, update_fields, commit, self_close)
+    else:
+        if self_close:
+            executor.close()
+        raise ValueError("insert_fields must be a dict or a non-empty list of dicts")
+
+
+def _build_insert_sql(table_name, fields, skip_duplicate=False):
+    """构建插入SQL语句的公共方法"""
+    field_names = ', '.join(fields)
+    placeholders = '(' + ', '.join(['%s'] * len(fields)) + ')'
+    insert_keyword = 'INSERT IGNORE' if skip_duplicate else 'INSERT'
+    return f'{insert_keyword} INTO {table_name} ({field_names}) VALUES {placeholders}'
+
+
+def _upsert_single(executor, table_name, data, update_fields, commit, self_close):
+    keys = list(data.keys())
+    insert_sql = f"INSERT INTO {table_name} ({', '.join(keys)}) VALUES ({', '.join(['%s'] * len(keys))})"
+    
+    # 确定要更新的字段
+    if update_fields is None:
+        # 更新所有字段
+        update_keys = keys
+    else:
+        # 只更新指定的字段
+        update_keys = [k for k in keys if k in update_fields]
+    
+    update_sql = ', '.join([f"{k} = VALUES({k})" for k in update_keys])
+    sql = f"{insert_sql} ON DUPLICATE KEY UPDATE {update_sql}"
+    executor.execute(sql, tuple(data.values()), commit=commit, self_close=self_close)
+    return 1
+
+
+def _upsert_batch(executor, table_name, data_list, update_fields, commit, self_close):
+    keys = list(data_list[0].keys())
+    insert_sql = f"INSERT INTO {table_name} ({', '.join(keys)}) VALUES ({', '.join(['%s'] * len(keys))})"
+    
+    # 确定要更新的字段
+    if update_fields is None:
+        # 更新所有字段
+        update_keys = keys
+    else:
+        # 只更新指定的字段
+        update_keys = [k for k in keys if k in update_fields]
+    
+    update_sql = ', '.join([f"{k} = VALUES({k})" for k in update_keys])
+    sql = f"{insert_sql} ON DUPLICATE KEY UPDATE {update_sql}"
+    values = [tuple(d.values()) for d in data_list]
+    executor.execute(sql, values, commit=commit, self_close=self_close)
+    return len(data_list)
+
+
+def _bulk_insert_load_data(executor, table_name, insert_fields, skip_duplicate=False, 
                           commit=True, batch_size=50000, temp_dir=None, self_close=False):
     """
     使用LOAD DATA INFILE进行超高速批量插入，专为百万级数据量优化
@@ -161,7 +217,7 @@ def _bulk_insert_load_data(executor: SQLExecutor, table_name, insert_fields, ski
     return inserted_count
 
 
-def _executemany_optimized(executor: SQLExecutor, table_name, insert_fields, skip_duplicate=False, 
+def _executemany_optimized(executor, table_name, insert_fields, skip_duplicate=False, 
                           commit=True, batch_size=10000, self_close=False):
     """
     优化的分批executemany插入，适合1-50万数据量
